# Security Policy

## Reporting a Vulnerability

If you discover a potential security vulnerability, please email [lvieira+eventide@lvieira.com](mailto:lvieira+eventide@lvieira.com).

Please do not open public issues for security vulnerabilities.

---

## Bug Bounties

While we encourage and appreciate security reports,
Eventide does not currently have a bug bounty program.

---

## Vulnerability Disclosures

Critical vulnerabilities will be disclosed publicly via GitHub's
[Security Advisory](https://github.com/lvieirajr/eventide/security/advisories) system.
